Examples
========

Write to and read from file (generic example)
---------------------------------------------


Write to file (HEP example)
---------------------------
.. include:: examples/write_HEP.rst

Read from file (HEP example)
----------------------------

Converting .csv files to hepfile
--------------------------------

More examples here. 
